==> haskell-hxt-charproperties-9.5.0.0-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hxt-charproperties.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hxt-charproperties
version:              9.5.0.0
visibility:           public
id:                   hxt-charproperties-9.5.0.0-7S8DfdpAeUp1ftDSlDNoDk
key:                  hxt-charproperties-9.5.0.0-7S8DfdpAeUp1ftDSlDNoDk
license:              MIT
copyright:            Copyright (c) 2010- Uwe Schmidt
maintainer:           Uwe Schmidt <uwe@fh-wedel.de>
author:               Uwe Schmidt
stability:            Stable
homepage:             https://github.com/UweSchmidt/hxt
synopsis:             Character properties and classes for XML and Unicode
description:
    Character properties defined by XML and Unicode standards.
    These modules contain predicates for Unicode blocks,
    char properties
    and character predicates defined by XML.
    Supported Unicode version is 13.0.0
    9.4.0.0: Supported Unicode version 12.1.0
    9.3.0.2: Supported Unicode version 9.0.0

category:             Text
abi:                  987238cefcc58e9ac895e7211dd1ec9b
exposed:              True
exposed-modules:
    Data.Char.Properties.UnicodeBlocks
    Data.Char.Properties.UnicodeCharProps
    Data.Char.Properties.XMLCharProps Data.Set.CharSet

import-dirs:          /usr/lib/ghc-9.0.1/site-local/hxt-charproperties-9.5.0.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/hxt-charproperties-9.5.0.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/hxt-charproperties-9.5.0.0

hs-libraries:         HShxt-charproperties-9.5.0.0-7S8DfdpAeUp1ftDSlDNoDk
depends:              base-4.15.0.0
haddock-interfaces:
    /usr/share/doc/haskell-hxt-charproperties/html/hxt-charproperties.haddock

haddock-html:         /usr/share/doc/haskell-hxt-charproperties/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hxt-charproperties-9.5.0.0-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hxt-charproperties.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hxt-charproperties
version:              9.5.0.0
visibility:           public
id:                   hxt-charproperties-9.5.0.0-BUzcmi88CMq3OISKIjEA5L
key:                  hxt-charproperties-9.5.0.0-BUzcmi88CMq3OISKIjEA5L
license:              MIT
copyright:            Copyright (c) 2010- Uwe Schmidt
maintainer:           Uwe Schmidt <uwe@fh-wedel.de>
author:               Uwe Schmidt
stability:            Stable
homepage:             https://github.com/UweSchmidt/hxt
synopsis:             Character properties and classes for XML and Unicode
description:
    Character properties defined by XML and Unicode standards.
    These modules contain predicates for Unicode blocks,
    char properties
    and character predicates defined by XML.
    Supported Unicode version is 13.0.0
    9.4.0.0: Supported Unicode version 12.1.0
    9.3.0.2: Supported Unicode version 9.0.0

category:             Text
abi:                  2f70ab14ce1a322bb91a3b254123a81f
exposed:              True
exposed-modules:
    Data.Char.Properties.UnicodeBlocks
    Data.Char.Properties.UnicodeCharProps
    Data.Char.Properties.XMLCharProps Data.Set.CharSet

import-dirs:          /usr/lib/ghc-9.0.2/site-local/hxt-charproperties-9.5.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hxt-charproperties-9.5.0.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.2/hxt-charproperties-9.5.0.0

hs-libraries:         HShxt-charproperties-9.5.0.0-BUzcmi88CMq3OISKIjEA5L
depends:              base-4.15.1.0
haddock-interfaces:
    /usr/share/doc/haskell-hxt-charproperties/html/hxt-charproperties.haddock

haddock-html:         /usr/share/doc/haskell-hxt-charproperties/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
